@@ -13,9 +13,9 @@ module PuppetMetadata
     # The EOL dates for the various operating systems
     # @see .eol_date
     EOL_DATES = {
-      # https://almalinux.org/ FAQ at the bottom
+      # https://wiki.almalinux.org/release-notes/
       'AlmaLinux' => {
-        '9' => nil,
+        '9' => '2032-05-31',
         '8' => '2029-05-31',
       },
       # https://endoflife.software/operating-systems/linux/centos
@@ -28,13 +28,12 @@ module PuppetMetadata
         '4' => '2012-02-29',
         '3' => '2010-10-30',
       },
-      # https://endoflife.software/operating-systems/linux/debian
       # https://wiki.debian.org/DebianReleases
       'Debian' => {
         # TODO: EOL is standard support, not the extended life cycle
         '12' => nil, # '~2026',
         '11' => nil, # '~2024',
-        '10' => nil, # '~2022',
+        '10' => '2022-09-10',
         '9' => '2020-07-06',
         '8' => '2018-06-17',
         '7' => '2016-04-26',
@@ -52,11 +51,20 @@ module PuppetMetadata
         '8' => '2029-07-01',
         '7' => '2024-12-31',
       },
-      # https://endoflife.software/operating-systems/linux/fedora
+      # https://docs.fedoraproject.org/en-US/releases/eol/
       'Fedora' => {
-        '32' => nil,
-        '31' => nil,
-        '30' => nil,
+        '41' => nil,
+        '40' => nil,
+        '39' => nil,
+        '38' => '2024-05-21',
+        '37' => '2023-12-05',
+        '36' => '2023-05-16',
+        '35' => '2022-12-13',
+        '34' => '2022-06-07',
+        '33' => '2021-11-30',
+        '32' => '2021-05-25',
+        '31' => '2020-11-24',
+        '30' => '2020-05-26',
         '29' => '2019-11-26',
         '28' => '2019-05-28',
         '27' => '2018-11-30',
@@ -110,9 +118,9 @@ module PuppetMetadata
         '4' => '2012-02-29',
         '3' => '2010-10-31',
       },
-      # https://endoflife.date/rocky-linux
+      # https://wiki.rockylinux.org/rocky/version/
       'Rocky' => {
-        '9' => nil,
+        '9' => '2032-05-31',
         '8' => '2029-05-31',
       },
       # https://endoflife.software/operating-systems/linux/ubuntu
@@ -220,11 +228,6 @@ module PuppetMetadata
       # @return [Optional[Integer]] The Puppet major version, if any
       def os_release_puppet_version(operatingsystem, release)
         case operatingsystem
-        when 'Debian'
-          case release
-          when '12'
-            7
-          end
         when 'Fedora'
           case release
           when '39', '40'
